@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::GithubMeta;
-$Dist::Zilla::Plugin::GithubMeta::VERSION = '0.50';
+$Dist::Zilla::Plugin::GithubMeta::VERSION = '0.54';
 # ABSTRACT: Automatically include GitHub meta information in META.yml
 
 use strict;
@@ -58,7 +58,9 @@ sub _acquire_repo_info {
   {
     my $gitver = `git version`;
     my ($ver) = $gitver =~ m!git version ([0-9.]+(\.msysgit)?[0-9.]+)!;
-    $ver =~ s/\.msysgit//;
+    $ver =~ s![^\d._]!!g;
+    $ver =~ s!\.$!!;
+    $ver =~ s!\.+!.!g;
     chomp $gitver;
     require version;
     my $ver_obj = try { version->parse( $ver ) }
@@ -188,7 +190,7 @@ Dist::Zilla::Plugin::GithubMeta - Automatically include GitHub meta information
 
 =head1 VERSION
 
-version 0.50
+version 0.54
 
 =head1 SYNOPSIS
 
